package org.apache.commons.lang3.time;

import java.util.Date;
import java.util.TimeZone;

/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: org_apache_commons_lang3_time.jar:org/apache/commons/lang3/time/GmtTimeZone.class */
public class GmtTimeZone extends TimeZone {
    private static final int MILLISECONDS_PER_MINUTE = 60000;
    private static final int MINUTES_PER_HOUR = 60;
    private static final int HOURS_PER_DAY = 24;
    static final long serialVersionUID = 1;
    private final int offset;
    private final String zoneId;

    /* JADX INFO: Access modifiers changed from: package-private */
    public GmtTimeZone(boolean negate, int hours, int minutes) {
        if (hours >= HOURS_PER_DAY) {
            throw new IllegalArgumentException(hours + " hours out of range");
        }
        if (minutes >= MINUTES_PER_HOUR) {
            throw new IllegalArgumentException(minutes + " minutes out of range");
        }
        int milliseconds = (minutes + (hours * MINUTES_PER_HOUR)) * MILLISECONDS_PER_MINUTE;
        this.offset = negate ? -milliseconds : milliseconds;
        this.zoneId = twoDigits(twoDigits(new StringBuilder(9).append(TimeZones.GMT_ID).append(negate ? '-' : '+'), hours).append(':'), minutes).toString();
    }

    private static StringBuilder twoDigits(StringBuilder sb, int n) {
        return sb.append((char) (48 + (n / 10))).append((char) (48 + (n % 10)));
    }

    @Override // java.util.TimeZone
    public int getOffset(int era, int year, int month, int day, int dayOfWeek, int milliseconds) {
        return this.offset;
    }

    @Override // java.util.TimeZone
    public void setRawOffset(int offsetMillis) {
        throw new UnsupportedOperationException();
    }

    @Override // java.util.TimeZone
    public int getRawOffset() {
        return this.offset;
    }

    @Override // java.util.TimeZone
    public String getID() {
        return this.zoneId;
    }

    @Override // java.util.TimeZone
    public boolean useDaylightTime() {
        return false;
    }

    @Override // java.util.TimeZone
    public boolean inDaylightTime(Date date) {
        return false;
    }

    public String toString() {
        return "[GmtTimeZone id=\"" + this.zoneId + "\",offset=" + this.offset + ']';
    }

    public int hashCode() {
        return this.offset;
    }

    public boolean equals(Object other) {
        return (other instanceof GmtTimeZone) && this.zoneId == ((GmtTimeZone) other).zoneId;
    }
}
